@@ -14,6 +14,7 @@
 import logging
 import os
 import sys
+import warnings
 import webbrowser
 from threading import Thread
 from typing import (
@@ -64,6 +65,15 @@ from .utils import (
 
 LOGGER = logging.getLogger(__name__)
 
+warnings.formatwarning = lambda message, *args, **kwargs: f"{message}\n"
+if sys.version_info.minor < 8:
+    warnings.warn(
+        "You are currently using Python 3.7. "
+        "Boulder Opal will soon remove support for Python 3.7 "
+        "since it will reach its end-of-life status on June 26th, 2023.",
+        FutureWarning,
+    )
+
 
 class Qctrl:
     """A mediator class. Used to authenticate with Q-CTRL and access Q-CTRL features.
