@@ -14,7 +14,7 @@
 import logging
 import re
 import sys
-from collections import namedtuple
+from dataclasses import dataclass
 from enum import Enum
 from functools import wraps
 from pathlib import Path
@@ -227,12 +227,26 @@ def check_client_version(func):
     return _check_client_version
 
 
-# a namedtuple to define basic information of a package
-# name : the official name of the package
-# pkg_name : installed packaged name
-# url : the URL for hosting the package on PyPI
-# imported when locally available
-_PackageInfo = namedtuple("_PackageInfo", ["name", "pkg_name", "url"])
+@dataclass
+class _PackageInfo:
+    """
+    Store basic information of a package
+
+    Parameters
+    ----------
+    name : str
+        The official name of the package
+    pkg_name : str
+        Installed packaged name
+    url : str
+        The URL for hosting the package on PyPI.
+    """
+
+    name: str
+    pkg_name: str
+    url: str
+
+
 _QCTRL_URL = "https://pypi.org/pypi/qctrl/json"
 
 
@@ -365,7 +379,6 @@ def print_environment_related_packages():
         "qctrlcommons",
         "qctrlmloop",
         "qctrlopencontrols",
-        "qctrlpyquil",
         "qctrlqua",
         "boulderopaltoolkits",
         "qctrlvisualizer",
